pub struct StridedMapMutSimd<'a, T>{ /* private fields */ }Expand description
A SIMD-optimized mutable mapped strided iterator over tensor elements.
This struct provides mutable access to tensor elements with SIMD optimizations, allowing for efficient parallel processing of tensor data.
Implementations
Sourceimpl<'a, T> StridedMapMutSimd<'a, T>
impl<'a, T> StridedMapMutSimd<'a, T>
Sourcepub fn new<U: TensorInfo<T>>(res_tensor: U) -> Self
pub fn new<U: TensorInfo<T>>(res_tensor: U) -> Self